﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace wpfWorkItemListViewer
{
    /// <summary>
    /// Interaction logic for DynamicDataGrid.xaml
    /// </summary>
    public partial class DynamicDataGrid : UserControl
    {
        public DynamicDataGrid()
        {
            InitializeComponent();
        }




        public List<WorkListItem> Items
        {
            get { return (List<WorkListItem>)GetValue(ItemsProperty); }
            set { SetValue(ItemsProperty, value); }
        }

        
        public static readonly DependencyProperty ItemsProperty =
            DependencyProperty.Register("Items", typeof(List<WorkListItem>), typeof(DynamicDataGrid), new PropertyMetadata(null, OnItemsPropertyChanged));

        private static void OnItemsPropertyChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            (d as DynamicDataGrid).BuildColumns();
        }

        private void BuildColumns()
        {
            this.dgd.ItemsSource = this.Items;
            
            this.Items[0].Items.Keys.ToList<string>().ForEach(s => this.dgd.Columns.Add(new ExtendedDataGridColumn() { Header = s}));

            foreach (var col in this.dgd.Columns)
            {
                (col as ExtendedDataGridColumn).WLI = this.Items;
            }
        }       
    }

    public class ExtendedDataGridColumn : DataGridTextColumn
    {
        public Dictionary<string,string> DictItems { get; set; }

        public List<WorkListItem> WLI { get; set; }


        protected override FrameworkElement GenerateElement(DataGridCell cell, object dataItem)
        {
            if ((dataItem as WorkListItem) != null)
            {
                string val;
                (dataItem as WorkListItem).Items.TryGetValue(this.Header.ToString(), out val);
                return new TextBlock() { Text = val };
            }
            return null;
        }            
    }
}
